<?php

/**
 * The main class of the plugin.
 * All the magic happens here.
 */
class GpxPlugin {

	/**
	 * Callback function called for [gpx] tags which returns the HTML code for the map.
	 *
	 * @param unknown $action
	 * @param array $attr
	 *        	the attributes given in the tag
	 * @param unknown $content
	 * @param unknown $params
	 * @param unknown $node_object
	 * @return boolean|string the HTML code for the map
	 */
	static function getGpxHtml($action, $attr, $content, $params, $node_object) {
		if ($action == 'validate') {
			// not used for now
			return true;
		}
		// FIXME:
		// - GPXviewer kann auch mehrere Dateien -> die müssen dann kommasepariert übergeben werden
		// - Lizenz GPX Viewer? -> Lizenz Plugin?
		// - JS-Parameter als custom.js ins res-Verzeichnis?
		// -> Dateiname sollte nicht angezeigt werden
		// - welche Parameter kann/sollte das [gpx]-Tag haben?
		// - feste Größe für das DIV? Oder lieber ausklappbar?
		// - Doku, Doku, Doku

		$filePath = $attr ['default'];
		// check given file path
		try {
			$filePathRel = self::getFilePath($filePath);
		} catch (\Exception $e) {
			return $e->getMessage();
		}

		$filePathRel = self::getRelativeFilePathFromCurrentUrl($filePathRel);

		// FIXME: Localize
		$noJsError = 'Sorry, this does not work without JavaScript.';

		// GPX Viewer needs a unique ID for the DIVs
		$divId = uniqid('gpx_');

		$mapDiv = '<div id="' . $divId . '" class="gpxmap gpxview:' . $filePathRel . '"><noscript><p>' . $noJsError . '</p></noscript></div>';
		$heightprofileDiv = '<div id="' . $divId . '_hp" class="gpxheightprofile"><noscript><p>' . $noJsError . '</p></noscript></div>';

		$html = '<div class="gpx">' . $mapDiv . $heightprofileDiv . '</div>';
		return $html;
	}

	/**
	 * Calculates the relative file path regarding the current setting of the PrettyURLs plugin
	 *
	 * @param string $filePathRel
	 * @return string
	 */
	private static function getRelativeFilePathFromCurrentUrl($filePathRel) {
		// get the plugin list
		include (getcwd() . '/fp-content/config/plugins.conf.php');

		$prettyUrlsMode = -1;
		// if PrettyUrls plugin is enabled
		if (in_array('prettyurls', $fp_plugins)) {
			// get its mode
			$prettyUrlsMode = plugin_getoptions('prettyurls', 'mode');
		}

		$currentUrl = (isset($_SERVER ['HTTPS']) && $_SERVER ['HTTPS'] === 'on' ? "https" : "http") . '://' . $_SERVER ['HTTP_PROTOCOL'] . $_SERVER ['HTTP_HOST'] . $_SERVER ['REQUEST_URI'];
		$relFromUrl = substr($currentUrl, strlen(BLOG_BASEURL));
		$noOfSlashes = substr_count($relFromUrl, '/');
		switch ($prettyUrlsMode) {
			case 0: // Automatic
			case 2: // HTTP Get ,e.g. /?u=/2011/01/01/hello-world/
				return $filePathRel;
				break;
			case 1: // Path Info, e.g. /index.php/2011/01/01/hello-world/
				for($i = 0; $i < $noOfSlashes; $i++) {
					$filePathRel = '../' . $filePathRel;
				}
				return $filePathRel;
				break;
			case 3: // Pretty, e.g. /2011/01/01/hello-world/
				for($i = 0; $i < $noOfSlashes + 1; $i++) {
					$filePathRel = '../' . $filePathRel;
				}
				return $filePathRel;
				break;
			// PrettyURLs disabled
			default:
				return $filePathRel;
				break;
		}

		return $filePathRel;
	}

	/**
	 * Returns the relative path of the given gpx file.
	 *
	 * @param string $path
	 *        	the path to validate
	 * @throws Exception if the path is invalid
	 * @return string the relative path
	 */
	private static function getFilePath($file) {
		// prevent path traversal
		if (strpos($file, '..') !== false) {
			throw new Exception('Invalid file given');
		}
		// check if file exists
		$filePathRel = 'fp-content/' . $file;
		if (!file_exists($filePathRel)) {
			throw new Exception('Given file does not exist.');
		}
		return $filePathRel;
	}

	/**
	 * Initializes the BBCode tags of the plugin.
	 */
	function initializePluginTags() {
		// get the global bbcode object
		$bbcode = plugin_bbcode_init();

		// add tag "audioplayer"
		$bbcode->addCode('gpx', // tag name: this will go between square brackets
		'callback_replace_single', // type of action: we'll use a callback function
		'GpxPlugin::getGpxHtml', // name of the callback function
		array(
			'usecontent_param' => array(
				'default'
			)
		), // supported parameters: "default" is [acronym=valore]
		'block', // type of the tag, inline or block, etc
		array(
			'listitem',
			'block'
		), // type of elements in which you can use this tag
		array()); // type of elements where this tag CAN'T go (in this case, none, so it can go everywhere)
		$bbcode->setCodeFlag('gpx', 'closetag', BBCODE_CLOSETAG_FORBIDDEN); // a closing tag is forbidden (no [/tag])
	}

	/**
	 * Header hook for loading the GPX viewer scripts.
	 * Echoes the <script> tags.
	 */
	static function echoScriptTags() {
		$pdir = plugin_geturl('gpx');
		echo '<!-- GPX plugin -->
	<script type="text/javascript" src="' . $pdir . 'res/GPXViewer6.9/GM_Utils/GPX2GM.js"></script>
	<script type="text/javascript" src="' . $pdir . 'res/customsettings.js"></script>
	<link href="' . $pdir . 'res/gpxplugin.css" rel="stylesheet" type="text/css"/>
	<!-- /GPX plugin -->';
	}

} // class GpxPlugin