<?php

/**
 * Plugin Name: GPX Viewer
 * Version: 1.0
 * Plugin URI: https://www.arvidzimmermann.de
 * Description: Includes the free JS library <a href="https://www.j-berkemeier.de/GPXViewer/">GPX Viewer</a> to display GPX routes/tracks on a map.<br>Simply upload a GPX file and add it to your blog: [gpx="attachs/file.gpx"]
 * Author: Arvid Zimmermann
 * Author URI: https://www.arvidzimmermann.de
 */

/**
 * --------
 * About
 * --------
 *
 * This plugin adds Jürgen Berkemeier's free JS library "GPX Viewer" - https://www.j-berkemeier.de/GPXViewer/ - to FlatPress.
 * It adds a BBCode tag "gpx" to include your uploaded GPX file into your blog entry or static page.
 *
 * --------
 * Usage
 * --------
 * Upload a GPX file to your FlatPress instance.
 * Edit your static page or blog entry.
 * Add: [gpx="attachs/file.gpx"]
 *
 * --------
 * HTML+CSS
 * --------
 *
 * The plugin's output consists of two parts: The map itself and a height profile plot.
 * The map is displayed as <div class="gpxmap">, the height profile plot as <div class="gpxheightprofile">.
 * Those two are packed together in a <div class="gpx">.
 *
 * You find CSS defintions for these classes in res/gpxplugin.css.
 *
 * --------
 * Customization
 * --------
 * The GPX Viewer library allows to change appearance of the map and height profile (such as colors and other behaviour) via JavaScript control variables.
 * The file res/costumsettings.js contains a few of them to start with; you find them all at https://www.j-berkemeier.de/GPXViewer/#ctrls .
 *
 * --------
 * License
 * --------
 * GPX Viewer by Jürgen Berkemeier: CC BY-NC-SA 4.0. If you want to use it for commercial purposes, please contact the author: https://www.j-berkemeier.de/
 * GPX Viewer uses Leaflet API (https://leafletjs.com) by Vladimir Agafonkin, which is licensed under BSD 2-Clause "Simplified" License.
 * GPX data is shown on OpenStreetMap maps (https://www.openstreetmap.org/) , licensed under ODbL (https://www.openstreetmap.org/copyright/).
 * The FlatPress plugin code around all this by Arvid Zimmermann (https://arvidzimmermann.de) is licensed under GPLv3.
 */

// include the plugin's PHP files
include_once dirname(__FILE__) . '/gpxplugin.class.php';

// intialize the BBCode tags of the plugin
add_filter('init', 'GpxPlugin::initializePluginTags');

// inject neccessary JS+CSS in the <head> section
add_action('wp_head', 'GpxPlugin::echoScriptTags', 0);

